package org.antforge.waqlpp.test;

import java.io.StringReader;

import junit.framework.Assert;

import org.antforge.waqlpp.parser.ParseException;
import org.antforge.waqlpp.parser.Parser;
import org.antforge.waqlpp.parser.SimpleNode;
import org.junit.Test;

public class ParserTest
{
	private static Parser prepare(String input) {
		return new Parser(new StringReader(input));
	}

	@Test
	public void testDependencyIdentifierGiven() throws ParseException {
		SimpleNode n = prepare("$23{//foo/bar}").pDataDependency();
		Assert.assertEquals(23, n.jjtGetValue());
		Assert.assertEquals(1, n.jjtGetNumChildren());
	}

	@Test
	public void testDependencyIdentifierMissing() throws ParseException {
		SimpleNode n = prepare("${//foo/bar}").pDataDependency();
		Assert.assertEquals(null, n.jjtGetValue());
		Assert.assertEquals(1, n.jjtGetNumChildren());
	}

	@Test(expected = NumberFormatException.class)
	public void testDependencyIdentifierOverflow() throws ParseException {
		prepare("$999999999999{//foo/bar}").pDataDependency();
	}

	@Test(expected = ParseException.class)
	public void testDependencyPathMalformed() throws ParseException {
		prepare("${<bug>}").pDataDependency();
	}

	@Test(expected = ParseException.class)
	public void testDependencyPathMissing() throws ParseException {
		prepare("${}").pDataDependency();
	}

	@Test
	public void testTemplateIdentifierGiven() throws ParseException {
		SimpleNode n = prepare("$23(<foo/>)").pTemplateList();
		Assert.assertEquals(23, n.jjtGetValue());
		Assert.assertEquals(1, n.jjtGetNumChildren());
	}

	@Test
	public void testTemplateIdentifierMissing() throws ParseException {
		SimpleNode n = prepare("$(<foo/>)").pTemplateList();
		Assert.assertEquals(null, n.jjtGetValue());
		Assert.assertEquals(1, n.jjtGetNumChildren());
	}

	@Test(expected = NumberFormatException.class)
	public void testTemplateIdentifierOverflow() throws ParseException {
		prepare("$999999999999(<foo/>)").pTemplateList();
	}

	@Test
	public void testTemplateList1() throws ParseException {
		SimpleNode n = prepare("$(<foo/>,<bar>x</bar>,<baz/>)").pTemplateList();
		Assert.assertEquals(3, n.jjtGetNumChildren());
	}

	@Test
	public void testTemplateList2() throws ParseException {
		SimpleNode n = prepare("$('foo','bar','some string','another,string')").pTemplateList();
		Assert.assertEquals(4, n.jjtGetNumChildren());
	}

	@Test
	public void testTemplateList3() throws ParseException {
		SimpleNode n = prepare("$(\"foo\",\"bar,baz\")").pTemplateList();
		Assert.assertEquals(2, n.jjtGetNumChildren());
	}

	@Test
	public void testTemplateList4() throws ParseException {
		SimpleNode n = prepare("$(2, 3, 5, 7, 11, 13, 17, 19, 23, 29)").pTemplateList();
		Assert.assertEquals(10, n.jjtGetNumChildren());
	}

	@Test
	public void testTemplateListMixed() throws ParseException {
		SimpleNode n = prepare("$('foo', \"bar\", <test></test>, 23)").pTemplateList();
		Assert.assertEquals(4, n.jjtGetNumChildren());
	}

	@Test(expected = ParseException.class)
	public void testTemplateListEmpty() throws ParseException {
		prepare("$()").pTemplateList();
	}

	@Test(expected = ParseException.class)
	public void testTemplateListMarlformed() throws ParseException {
		prepare("$(<foo/>,)").pTemplateList();
	}

	@Test
	public void testDollarEscaped() throws ParseException {
		prepare("<test>$$</test>").parse();
	}

	@Test(expected = ParseException.class)
	public void testDollarUnescaped() throws ParseException {
		prepare("<test>$</test>").parse();
	}
}
